@@ -63,10 +63,11 @@ roundPlotMark<-function(roundness, xMark, yMark,
                   y=y,
                   col= dfMarkColorInternal$markColor[match(     z   , dfMarkColorInternal$markName)],
                   lwd=lwd.chr,
-                  border = ifelse(dfMarkColorInternal$markColor[match(z,dfMarkColorInternal$markName)]=="white",
-                  "black",
-                  dfMarkColorInternal$markColor[match(z,dfMarkColorInternal$markName)]
-                          ) # ifelse
+                  border =
+                    # ifelse(dfMarkColorInternal$markColor[match(z,dfMarkColorInternal$markName)]=="white",
+                  # "black",
+                  dfMarkColorInternal$markBorderColor[match(z,dfMarkColorInternal$markName)]
+                          # ) # ifelse
                 ), # pol
               x=xMark[[w]],
               y=yMark[[w]]
@@ -117,17 +118,6 @@ if(legend=="inline"){
 
     yModMark<-yMark # yMark
 
-    topline_y<-list()
-    bottomline_y<-list()
-    topBotline_x<-list()
-    x2_1<-list()
-    x2_2<-list()
-    y2_1<-list()
-    y2_2<-list()
-    xy_1<-list()
-    xy_2<-list()
-    xy_3<-list()
-    xy_4<-list()
     newLongx<-list()
     newLongy<-list()
 
@@ -152,8 +142,8 @@ if(legend=="inline"){
       newLongx[[s]]<-xyCoords$newLongx
       newLongy[[s]]<-xyCoords$newLongy
 
-      attr(newLongy[[s]],"sqname") <- attr(yMark[[s]],"sqname")
-      attr(newLongx[[s]],"sqname") <- attr(xMark[[s]],"sqname")
+      attr(newLongy[[s]],"spname") <- attr(yMark[[s]],"spname")
+      attr(newLongx[[s]],"spname") <- attr(xMark[[s]],"spname")
 
     } # for
     names(newLongy)<-names(yMark)
@@ -195,7 +185,9 @@ if(legend=="inline"){
 
       drawPlotMark(circleMapsMarks,dfMarkColorInternal,listOfdfMarkPosSq,lwd.chr)
 if(legend=="inline"){
-      circLabelMark(circleMapsLabels,listOfdfMarkPosSq,markLabelSize,pattern)
+
+     # circLabelMark(circleMaps,     listOfdfMarkPos, markLabelSize,pattern,labelOutwards,circleCenter,circleCenterY,iscM=FALSE)
+      circLabelMark(circleMapsLabels,listOfdfMarkPosSq,markLabelSize,pattern,labelOutwards,circleCenter,circleCenterY)
 }
 
     } # circular
